# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import UI, Common, ComplianceConfiguration, Properties

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import ProgressEventArgs
from .Compliance import (
    AuditTrailDataSet,
    IAuditTrail,
    IBatchFileService,
    ICommandPermission,
    ICompliance,
    IComplianceCommand,
    IDataStorage,
    IFileInfo,
    IImpersonationContext,
    ILogonECM,
    IReportCompliance,
    IReportFileService,
    IRevisionHistory,
    IUnknownsFileService,
)
from .ComplianceUI import (
    FileDialogMode,
    IBatchDialog,
    IComplianceConfigurationEdit,
    IComplianceUI,
    IFileAndFolderDialog,
    IFileDialog,
    IFolderDialog,
    ILibraryDialog,
    ILogonDialog,
    IMethodDialog,
    ISampleFileDialog,
    IUnknownsFileDialog,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM

class AuditTrail(IAuditTrail, System.IDisposable):  # Class
    def __init__(self) -> None: ...

    AlwaysAuditTrail: bool  # readonly
    IsAuditTrailing: bool  # readonly
    IsReadOnly: bool  # readonly

    def LockAuditTrail(self) -> AuditTrailDataSet: ...
    def SaveAuditTrail(self) -> None: ...
    def UnlockAuditTrail(self) -> None: ...
    def Dispose(self) -> None: ...
    def AddEntry(
        self, command: IComplianceCommand, exception: System.Exception
    ) -> None: ...

class BatchFileService(IBatchFileService, System.IDisposable):  # Class
    DefaultDataFolder: str  # readonly

    def BeforeNewBatch(
        self, batchFolder: str, batchFile: str, auditTrail: bool
    ) -> None: ...
    def TranslateMethodToLocalPath(
        self, methodPath: str, revisionNumber: str
    ) -> str: ...
    def AfterNewBatch(self, error: bool) -> None: ...
    def AfterOpenBatch(self, error: bool) -> None: ...
    def UploadMethod(self, pathName: str, revisionNumber: str) -> None: ...
    def CheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def Dispose(self) -> None: ...
    def AfterSaveBatchAs(self, batchHashCode: str, hasError: bool) -> None: ...
    def BeforeClose(self) -> None: ...
    def PrepareLibrary(self, libraryPath: str, revisionNumber: str) -> None: ...
    def GetSampleFileNames(self, batchFolder: str) -> List[str]: ...
    def MethodExists(self, methodPath: str) -> bool: ...
    def BatchFileExists(self, batchFolder: str, batchFile: str) -> bool: ...
    def AfterSaveBatch(self, batchHashCode: str, hasError: bool) -> None: ...
    def UndoCheckoutBatch(self, batchFolder: str, batchFile: str) -> None: ...
    def BeforeOpenBatch(
        self, batchFolder: str, batchFile: str, readOnly: bool, revisionNumber: str
    ) -> None: ...
    def GetBatchFiles(self, folder: str) -> List[str]: ...
    def GetLatestMethodRevisionNumber(self, methodPath: str) -> str: ...
    def GetSampleInfo(self, samplePath: str) -> Dict[str, Any]: ...
    def LibraryExists(self, libraryPath: str) -> bool: ...
    def TranslateBatchToLocalPath(self, batchFile: str, revisionNumber: str) -> str: ...
    def GetMethodHistory(self, pathName: str) -> Iterable[IRevisionHistory]: ...
    def BeforeSaveBatchAs(self, batchFolder: str, batchFile: str) -> None: ...
    def GetLatestLibraryRevisionNumber(self, libraryPath: str) -> str: ...
    def GetBatchFileInfos(self, folder: str) -> List[IFileInfo]: ...
    def IsMethodFolder(self, methodPath: str) -> bool: ...
    def AfterClose(self, hasError: bool) -> None: ...
    def UploadLibrary(self, libraryPath: str, revisionNumber: str) -> None: ...
    def IsBatchCheckedoutByCurrentUser(
        self, batchFolder: str, batchFile: str
    ) -> bool: ...
    def BeforeSaveBatch(self) -> None: ...
    def AfterCloseMethod(self, methodPath: str) -> None: ...
    def PrepareMethod(self, methodPath: str, revisionNumber: str) -> None: ...
    def SampleFileExists(self, samplePath: str) -> bool: ...
    def GetBatchFilePath(self, batchFolder: str, batchFile: str) -> str: ...
    def PrepareSamples(self, samples: List[str]) -> None: ...
    def PrepareBatch(
        self, batchFolder: str, batchFile: str, progress: System.Action[int, int, str]
    ) -> None: ...
    def GetLatestBatchRevisionNumber(self, batchFolder: str, batchFile: str) -> str: ...

    Progress: System.EventHandler[ProgressEventArgs]  # Event

class CommandPermission(
    IReportCompliance, ICommandPermission, System.IDisposable
):  # Class
    CommandConfigurationKey: str = ...  # static # readonly
    CommandConfigurationKey_3x: str = ...  # static # readonly
    PrivilegeGroupPrefix_5x: str = ...  # static # readonly
    PrivilegePrefix_5x: str = ...  # static # readonly
    RolePrefix_5x: str = ...  # static # readonly

    CommandReason: str
    IsInCommandGroup: bool  # readonly
    Reporting: bool
    UserValidated: bool  # readonly
    UserValidationExecuted: bool

    def UserValidationRequiredCore(self, commandName: str) -> bool: ...
    @overload
    def CheckPreCommandCondition(self, command: IComplianceCommand) -> None: ...
    @overload
    def CheckPreCommandCondition(self, commandName: str) -> None: ...
    def BeginCommandGroup(self) -> None: ...
    def CommandReasonRequiredCore(self, commandName: str) -> bool: ...
    @overload
    def DemandPermission(self, commandName: str) -> None: ...
    @overload
    def DemandPermission(self, command: IComplianceCommand) -> None: ...
    def EndCommandGroup(self) -> None: ...
    def CommandReasonRequired(self, commandName: str) -> bool: ...
    @overload
    def HasPermission(self, commandName: str) -> bool: ...
    @overload
    def HasPermission(self, command: IComplianceCommand) -> bool: ...
    def ValidateUser(
        self, user: str, password: System.Security.SecureString
    ) -> None: ...
    def Dispose(self) -> None: ...
    def UserValidationRequired(self, commandName: str) -> bool: ...

    CommandGroupEnded: System.EventHandler  # Event
    CommandGroupStarted: System.EventHandler  # Event

class ComplianceECM(System.IDisposable, ILogonECM, IComplianceUI, ICompliance):  # Class
    def __init__(self) -> None: ...

    AuditTrail: IAuditTrail  # readonly
    BatchFileService: IBatchFileService  # readonly
    CommandPermission: ICommandPermission  # readonly
    Compliance: ICompliance  # readonly
    CurrentCommand: IComplianceCommand  # readonly
    DataStorage: IDataStorage  # readonly
    DisplayName: str  # readonly
    IsActive: bool  # readonly
    IsLocal: bool  # readonly
    LogonInfo: str  # readonly
    LogonRequired: bool  # readonly
    Name: str  # readonly
    ReportFileService: IReportFileService  # readonly
    Server: str  # readonly
    UnknownsFileService: IUnknownsFileService  # readonly
    UserName: str  # readonly
    Version: str  # readonly

    def CreateFileDialog(self, mode: FileDialogMode) -> IFileDialog: ...
    def SetupUpdateActivity(self) -> None: ...
    def CommandStart(self, command: IComplianceCommand) -> None: ...
    def GetUI(self) -> T: ...
    def LogonXml(self, xml: str) -> None: ...
    def CreateLogonDialog(self) -> ILogonDialog: ...
    def Dispose(self) -> None: ...
    @overload
    def Connect(self, compliance: ICompliance) -> None: ...
    @overload
    def Connect(self, token: str) -> None: ...
    def CreateMethodDialog(self, mode: FileDialogMode) -> IMethodDialog: ...
    def InitQuantCommandPermission(self) -> None: ...
    def CheckConnection(self) -> None: ...
    def CreateBatchDialog(self, mode: FileDialogMode) -> IBatchDialog: ...
    def CreateFileAndFolderDialog(
        self, mode: FileDialogMode
    ) -> IFileAndFolderDialog: ...
    def GetECM(self) -> Any: ...
    def CreateUnknownsFileDialog(self, mode: FileDialogMode) -> IUnknownsFileDialog: ...
    def CreateLibraryDialog(self, mode: FileDialogMode) -> ILibraryDialog: ...
    def Logon(
        self,
        server: str,
        domain: str,
        user: str,
        password: System.Security.SecureString,
        accountName: str,
    ) -> None: ...
    def GetToken(self) -> str: ...
    def CreateComplianceConfigurationEdit(self) -> IComplianceConfigurationEdit: ...
    def ValidateUser(
        self, username: str, password: System.Security.SecureString
    ) -> None: ...
    def CreateSampleFileDialog(self) -> ISampleFileDialog: ...
    def GetService(self) -> T: ...
    def CommandEnd(self, command: IComplianceCommand) -> None: ...
    def Impersonate(self) -> IImpersonationContext: ...
    def CreateFolderDialog(self) -> IFolderDialog: ...

class DataStorage(System.IDisposable, IDataStorage):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.ComplianceECM,
    ) -> None: ...

    InitialRevisionNumber: str  # readonly
    IsRevisionSupported: bool  # readonly
    OpenFolderSupported: bool  # readonly
    PathSeparator: str  # readonly

    def GetLatestRevisionNumber(self, path: str) -> str: ...
    @overload
    def UploadFile(self, pathName: str) -> None: ...
    @overload
    def UploadFile(self, pathName: str, revisionNumber: str) -> None: ...
    def Combine(self, paths: List[str]) -> str: ...
    @overload
    def DownloadFile(self, pathName: str) -> None: ...
    @overload
    def DownloadFile(self, pathName: str, revisionNumber: str) -> None: ...
    def GetFiles(self, folder: str, searchPattern: str) -> List[str]: ...
    def GetFolderPathName(self, pathName: str) -> str: ...
    def GetFileName(self, pathName: str) -> str: ...
    def GetHistory(self, pathName: str) -> Iterable[IRevisionHistory]: ...
    def GetNextRevisionNumber(self, path: str) -> str: ...
    def InitFolders(self) -> None: ...
    @overload
    def TranslateToLocalPath(self, path: str) -> str: ...
    @overload
    def TranslateToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    @staticmethod
    def ExtractZippedFolder(zipFilePath: str, destinationFolder: str) -> None: ...
    @staticmethod
    def GetSingleTopFolder(zarchive: System.IO.Compression.ZipArchive) -> str: ...
    def FileExists(self, path: str) -> bool: ...
    def GetFileInfos(self, folder: str, searchPattern: str) -> List[IFileInfo]: ...
    def OpenFolder(self, folderPath: str) -> None: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def IsMustangFile(
        zipFilePath: str, zarchive: System.IO.Compression.ZipArchive
    ) -> bool: ...
    def FolderExists(self, path: str) -> bool: ...
    def GetFolders(self, folder: str, searchPattern: str) -> List[str]: ...

class ImpersonateContext(System.IDisposable, IImpersonationContext):  # Class
    def Dispose(self) -> None: ...

class ReportFileService(IReportFileService, System.IDisposable):  # Class
    def DownloadFolderToWorkArea(self, path: str) -> None: ...
    def OpenFile(self, path: str) -> None: ...
    def DownloadFileToWorkArea(self, path: str) -> None: ...
    def UploadFileFromWorkArea(self, path: str) -> None: ...
    def GetDefaultOutputFolder(self, batchFolder: str, batchFile: str) -> str: ...
    def Print(self, path: str, printer: str) -> None: ...
    def TranslateToWorkPath(self, path: str) -> str: ...
    def DownloadFileAndUnzipToWorkArea(self, path: str) -> None: ...
    def Dispose(self) -> None: ...

class RevisionHistory(IRevisionHistory):  # Class
    def __init__(self) -> None: ...

    Date: Optional[System.DateTime]
    Reason: str
    RevisionNumber: str
    User: str

class UnknownsFileService(System.IDisposable, IUnknownsFileService):  # Class
    def GetAnalysisFilePath(self, batchFolder: str, analysisFile: str) -> str: ...
    def GetLatestAnalysisRevision(self, batchFolder: str, analysisFile: str) -> str: ...
    def AnalysisFileExists(self, batchFolder: str, analysisFile: str) -> bool: ...
    def TranslateAnalysisToLocalPath(self, path: str, revisionNumber: str) -> str: ...
    def DownloadAnalysisFile(
        self, batchFolder: str, analysisFile: str, revisionNumber: str
    ) -> None: ...
    def CheckoutAnalysis(self, batchFolder: str, analysisFile: str) -> None: ...
    def GetAnalysisFileInfos(self, folder: str) -> List[IFileInfo]: ...
    def UploadAnalysisFile(
        self, batchFolder: str, analysisFile: str, revisionNumber: str
    ) -> None: ...
    def UndoCheckoutAnalysis(self, batchFolder: str, analysisFile: str) -> None: ...
    def IsAnalysisCheckedoutByCurrentUser(
        self, batchFolder: str, analysisFile: str
    ) -> bool: ...
    def Dispose(self) -> None: ...
    def GetAnalysisFiles(self, folder: str) -> List[str]: ...

class Utilities:  # Class
    ZipExtension: str = ...  # static # readonly

    @staticmethod
    def RemoveZipExtension(path: str) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Utils

class CultureItem:  # Class
    def __init__(self, name: str) -> None: ...

    Culture: System.Globalization.CultureInfo  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly

    @staticmethod
    def GetSystemItems() -> (
        List[Agilent.MassHunter.Quantitative.Startup.Edit.Utils.CultureItem]
    ): ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Properties

# Stubs for namespace: Agilent.MSAcquisition.HashSignature

class CHashComponent(Agilent.MSAcquisition.HashSignature.IHashComponent):  # Class
    def __init__(self) -> None: ...

class ENUM_HASH_DATA_TYPE(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ACQ_DATA: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE = (
        ...
    )  # static # readonly
    ACQ_METHOD: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE = (
        ...
    )  # static # readonly
    ACQ_STUDY: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE = (
        ...
    )  # static # readonly
    GENERIC_FOLDER: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE = (
        ...
    )  # static # readonly
    XML_FILE: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE = (
        ...
    )  # static # readonly

class Globals:  # Class
    def __init__(self) -> None: ...

    AlgoVersionAttributeName: str = ...  # static # readonly
    BackupFileExtn: str = ...  # static # readonly
    ChecksumFileName: str = ...  # static # readonly
    ChecksumTagName: str = ...  # static # readonly
    DAMethodFolder: str = ...  # static # readonly
    DataFile_Extn: str = ...  # static # readonly
    DummyHashCode: str = ...  # static # readonly
    FileTagName: str = ...  # static # readonly
    FileToIncludeFromStudyRoot_BioAnalysisXltx: str = ...  # static # readonly
    FileToIncludeFromStudyRoot_MethodByInputFileTxt: str = ...  # static # readonly
    FilesToIncludeFromStudyRoot_FilesWithExtension_QuantScript: str = (
        ...
    )  # static # readonly
    FilesToIncludeFromStudyRoot_StudyLogTxt: str = ...  # static # readonly
    FolderTagName: str = ...  # static # readonly
    HashCodeAttributeName: str = ...  # static # readonly
    MainTagName: str = ...  # static # readonly
    MaxFileLength: int = ...  # static # readonly
    MethodFile_Extn: str = ...  # static # readonly
    NameTagName: str = ...  # static # readonly
    PathDelimeter: str = ...  # static # readonly
    RootFolder: str = ...  # static # readonly
    SSIZIPFile_Extn: str = ...  # static # readonly
    Schema1XMLFileString: str = ...  # static # readonly
    Schema2XMLFileString: str = ...  # static # readonly
    Schema2XMLString: str = ...  # static # readonly
    Schema3XMLFileString: str = ...  # static # readonly
    SchemaVersionAttributeName: str = ...  # static # readonly
    StudyFile_Extn: str = ...  # static # readonly
    SystemFolder: str = ...  # static # readonly
    VersionTagName: str = ...  # static # readonly
    VersionsFolder: str = ...  # static # readonly
    XMLFile_Extn: str = ...  # static # readonly

class IHashComponent(object):  # Interface
    def VerifyHashForFile(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        filePath: str,
    ) -> bool: ...
    def VerifyHashForFolder(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        path: str,
        foldersToInclude: str,
    ) -> bool: ...
    def GenerateHash(self, path: str, foldersToInclude: str) -> None: ...
    def VerifyHashForDataObject(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        path: str,
        foldersToInclude: str,
    ) -> bool: ...
    def GenerateHashForDataObject(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        path: str,
        foldersToInclude: str,
    ) -> None: ...
    def GenerateHashForFolder(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        path: str,
        foldersToInclude: str,
    ) -> None: ...
    def GenerateHashForFile(
        self,
        hashDataType: Agilent.MSAcquisition.HashSignature.ENUM_HASH_DATA_TYPE,
        filePath: str,
    ) -> None: ...
    def VerifyHash(self, path: str, foldersToInclude: str) -> bool: ...



# -*- coding: utf-8 -*-
import mh_operator_legacy as _

from mh_operator.legacy.common import get_argv, get_logger, global_state, is_main

global_state.LibraryAccess = LibraryAccess

from mh_operator.legacy.LibraryEdit import import_jcamps

logger = get_logger()

import glob
import logging
import os


def main():
    import argparse

    argv = get_argv()
    parser = argparse.ArgumentParser(
        prog=argv[0],
        description="Convert the MSP to .L (HP) format",
        epilog="Example: shebang --interpreter LEC MSP2HP.py -- --output 'C:\MassHunter\Library\demo.L' --verbose /path/to/jdx/dir/",
    )
    parser.add_argument("jdxs", nargs="+", help="The jcamp file or directory path")
    parser.add_argument("-o", "--output", help="The output library path")
    parser.add_argument(
        "-f",
        "--force",
        default=False,
        action="store_true",
        help="overwrite exsting library",
    )
    parser.add_argument(
        "-v", "--verbose", default=False, action="store_true", help="verbose logging"
    )
    args = parser.parse_args(argv[1:])

    if args.verbose:
        logger.addHandler(logging.StreamHandler())
        logger.setLevel(logging.DEBUG)
    logger.debug("file: {}, input: {}".format(__file__, args.output))

    jdx_path = []
    for p in args.jdxs:
        if os.path.isfile(p):
            jdx_path.append(p)
        else:
            jdx_path.extend(
                os.path.join(p, f) for f in os.listdir(p) if f.endswith(".jdx")
            )

    import_jcamps(jdx_path, os.path.abspath(args.output), overwrite=args.force)


if is_main(__file__):
    main()



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IChromPeak, IFXData, IonPolarity, MSScanType
from .FD import Feature, IScanSpace, Ridge, ScanConditions
from .FeatureDataAccess import RidgeSet
from .Quantitative import ITimeToMassConversion, QuantDataAccess, ScanRecord

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser

class BaselineRegion:  # Class
    ...

class CentroidSpectrum:  # Class
    def __init__(
        self,
        profileSpectrum: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrum,
    ) -> None: ...

    BasePeakIndex: int  # readonly
    Count: int  # readonly
    IsMassSpectrum: bool  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

class CentroidType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AbundanceWeighted: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidType
    ) = ...  # static # readonly
    Parabolic: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidType = (
        ...
    )  # static # readonly

class CentroidingFinishedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, e: System.EventArgs) -> None: ...

class CentroidingScanRecordEventArgs:  # Class
    def __init__(self, scanRecordIndex: int) -> None: ...

    ScanRecordIndex: int  # readonly

class CentroidingScanRecordEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingScanRecordEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingScanRecordEventArgs,
    ) -> None: ...

class CentroidingStartingEventArgs:  # Class
    def __init__(self, sampleDataPath: str, nScanRecords: int) -> None: ...

    NumScanRecords: int  # readonly
    SampleDataPath: str  # readonly

class CentroidingStartingEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingStartingEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingStartingEventArgs,
    ) -> None: ...

class FeatureDetectionFinishedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, e: System.EventArgs) -> None: ...

class FeatureDetectionScanRecordEventArgs:  # Class
    def __init__(self, scanRecordIndex: int) -> None: ...

    ScanRecordIndex: int  # readonly

class FeatureDetectionStartedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, e: System.EventArgs) -> None: ...

class FeatureDetectionStartingEventArgs:  # Class
    def __init__(self, sampleDataPath: str, nScanRecords: int) -> None: ...

    NumScanRecords: int  # readonly
    SampleDataPath: str  # readonly

class InterpolationType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Linear: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.InterpolationType = (
        ...
    )  # static # readonly
    Quadratic: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.InterpolationType
    ) = ...  # static # readonly

class MassCalResults:  # Class
    AValues: List[float]  # readonly
    AverageA: float  # readonly
    AverageT0: float  # readonly
    T0Values: List[float]  # readonly

class MassCalibrationOptions:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, optionsFile: str) -> None: ...

    DoMassCal: bool
    MaxRefMzDelta: float
    MinFoundRefMzsForTradFit: int
    MinFoundRefMzsPerRange: int
    ReferenceMassFilePath: str
    WriteMassCalResults: bool
    WriteRefMzResiduals: bool

class MassCalibrator:  # Class
    def __init__(
        self,
        dataAccess: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SpectrumDataAccess,
        options: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalibrationOptions,
    ) -> None: ...

    MassCalResults: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalResults
    )  # readonly
    MzSearchRangeDeltas: List[float]  # readonly
    RefMzCount: int  # readonly
    ReferenceMZs: List[float]  # readonly

    def ReadReferenceMasses(self, refMassFilePath: str) -> bool: ...
    def GetReferenceMassData(
        self, refMassIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ReferenceMassData: ...
    def SetMzSearchRange(self, mzSearchRangeDelta: float) -> None: ...

class PeakRegion:  # Class
    ...

class PeakShape:  # Class
    ...

class PeakShapeFit:  # Class
    ...

class ProfileDataCentroider:  # Class
    def __init__(
        self,
        dataNavigator: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SampleDataNavigator,
        massCal: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalibrator,
    ) -> None: ...

    Cancelled: bool  # readonly
    MassCalibration: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalibrator
    )  # readonly
    ScanRecordCount: int  # readonly

    def CancelCentroiding(self) -> None: ...
    def CentroidSampleData(self) -> None: ...

    CentroidingFinished: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingFinishedEventHandler
    )  # Event
    CentroidingScanRecordStarting: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingScanRecordEventHandler
    )  # Event
    CentroidingStarting: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidingStartingEventHandler
    )  # Event

class ProfileDataFeatureDetector:  # Class
    def __init__(
        self,
        dataNavigator: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SampleDataNavigator,
    ) -> None: ...

    Cancelled: bool  # readonly
    FeatureCount: int  # readonly
    IsFeatureDataPresent: bool  # readonly
    ProcessingTime: System.TimeSpan  # readonly
    RidgeCount: int  # readonly
    SampleDataPath: str  # readonly

    def Start(self) -> None: ...
    def Cancel(self) -> None: ...

    FeatureDetectionFinished: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionFinishedEventHandler
    )  # Event
    FeatureDetectionStarted: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionStartedEventHandler
    )  # Event
    RidgeDetectionCancelled: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeDetectionCancelledEventHandler
    )  # Event
    RidgeDetectionFinished: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeDetectionFinishedEventHandler
    )  # Event
    RidgeDetectionScanRecordProcessing: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeDetectionScanRecordEventHandler
    )  # Event
    RidgeDetectionStarting: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeDetectionStartingEventHandler
    )  # Event

class ProfileSpectrum:  # Class
    Count: int  # readonly
    IsMassSpectrum: bool  # readonly
    ScanRecord: ScanRecord  # readonly
    TimeToMassConversion: ITimeToMassConversion  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

    def ConvertMassToFlightTime(self, mass: float) -> float: ...
    def WriteCSV(self, sw: System.IO.StreamWriter) -> None: ...
    def FindPeaks(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrumPeak
    ]: ...

class ProfileSpectrumPeak:  # Class
    ApexIndex: int  # readonly
    CenterX: float  # readonly
    EndBaselineY: float  # readonly
    EndIndex: int  # readonly
    EndX: float  # readonly
    Height: float  # readonly
    InterpolatedPeakX: float  # readonly
    InterpolatedPeakY: float  # readonly
    IsMerged: bool  # readonly
    IsSaturated: bool  # readonly
    PeakRegion: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.PeakRegion
    )  # readonly
    PointCount: int  # readonly
    StartBaselineY: float  # readonly
    StartIndex: int  # readonly
    StartX: float  # readonly

class ProfileSpectrumPeakFinder:  # Class
    @overload
    def __init__(self, timeToMass: ITimeToMassConversion) -> None: ...
    @overload
    def __init__(
        self,
        options: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SpectrumPeakFinderOptions,
        timeToMass: ITimeToMassConversion,
    ) -> None: ...

    YMax: int  # readonly
    YMin: int  # readonly

    def FindSpectrumPeaks(
        self, xArray: List[float], yArray: List[float], satLimit: float
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrumPeak
    ]: ...

class ReferenceMassData:  # Class
    def __init__(
        self,
        massCal: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.MassCalibrator,
        refMzIndex: int,
        nScanLines: int,
    ) -> None: ...

    AbundanceFitResiduals: List[float]  # readonly
    AbundanceProfile: List[float]  # readonly
    MzDeltaProfile: List[float]  # readonly
    PointCount: int  # readonly
    ReferenceMass: float  # readonly
    ReferenceMassIndex: int  # readonly

    def ExcludeInterferenceRegions(
        self, peakList: System.Collections.Generic.List[IChromPeak]
    ) -> None: ...
    def FillInTheGaps(self) -> None: ...
    def FitAbundanceProfile(self) -> bool: ...
    def AddScanLineData(
        self, scanLineIndex: int, scanTime: float, mzDelta: float, abundance: float
    ) -> None: ...
    def InitExclusionMap(self) -> None: ...
    def IsExcluded(self, scanIndex: int) -> bool: ...
    @overload
    def FindAbundancePeaks(self) -> System.Collections.Generic.List[IChromPeak]: ...
    @overload
    def FindAbundancePeaks(
        self, xArray: List[float]
    ) -> System.Collections.Generic.List[IChromPeak]: ...

class RidgeDetectionCancelledEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, e: System.EventArgs) -> None: ...

class RidgeDetectionFinishedEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: System.EventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(self, sender: Any, e: System.EventArgs) -> None: ...

class RidgeDetectionScanRecordEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionScanRecordEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionScanRecordEventArgs,
    ) -> None: ...

class RidgeDetectionStartingEventHandler(
    System.MulticastDelegate,
    System.ICloneable,
    System.Runtime.Serialization.ISerializable,
):  # Class
    def __init__(self, object: Any, method: System.IntPtr) -> None: ...
    def EndInvoke(self, result: System.IAsyncResult) -> None: ...
    def BeginInvoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionStartingEventArgs,
        callback: System.AsyncCallback,
        object: Any,
    ) -> System.IAsyncResult: ...
    def Invoke(
        self,
        sender: Any,
        e: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.FeatureDetectionStartingEventArgs,
    ) -> None: ...

class RidgeFeatureInfo:  # Class
    Features: System.Collections.Generic.List[Feature]  # readonly
    Ridge: Ridge  # readonly
    ScanSpace: IScanSpace  # readonly

class SampleDataNavigator(System.IDisposable):  # Class
    def __init__(self, sampleDataDir: str) -> None: ...

    CollisionEnergy: float  # readonly
    CurrentRT: float  # readonly
    CycleNumber: int  # readonly
    DataAccess: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SpectrumDataAccess
    )  # readonly
    FragmentorVoltage: float  # readonly
    MultipleScanConditions: bool  # readonly
    MzOfInterest: float  # readonly
    Polarity: IonPolarity  # readonly
    PolarityString: str  # readonly
    RidgeSet: RidgeSet  # readonly
    SampleDataDir: str  # readonly
    ScanConditions: ScanConditions  # readonly
    ScanID: int  # readonly
    ScanIndex: int  # readonly
    ScanRecordCount: int  # readonly
    ScanType: MSScanType  # readonly

    @overload
    def GetCentroidTofSpectrum(
        self,
        profileSpectrum: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrum,
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidSpectrum: ...
    @overload
    def GetCentroidTofSpectrum(
        self, scanIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidSpectrum: ...
    def GetScanConditionsString(self) -> str: ...
    def GetCenteredDataRange(
        self, firstPointIndex: int, centerScanIndex: int, nScans: int, nPoints: int
    ) -> List[List[float]]: ...
    def ClearSpectrumCache(self) -> None: ...
    def GetTofSpectrum(
        self, scanIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrum: ...
    def GetDataRange(
        self, firstScanIndex: int, firstPointIndex: int, nScans: int, nPoints: int
    ) -> List[List[float]]: ...
    def GetPrevScanIndex_SameScanConditions(self) -> int: ...
    def CaptureRidgeInfo(
        self, scanIndex: int, x: float, xIsMass: bool
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.RidgeFeatureInfo: ...
    def GetCentroidMassSpectrum(
        self, scanIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidSpectrum: ...
    def XtoScanIndex(self, x: float, xNearestScanLine: float) -> int: ...
    def SameScanConditions(self, scanConditions: ScanConditions) -> bool: ...
    def Dispose(self) -> None: ...
    def GetTIC(self) -> IFXData: ...
    def GetNextScanIndex_SameScanConditions(self) -> int: ...
    def GetMassSpectrum(
        self, scanIndex: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrum: ...

class SpectrumDataAccess:  # Class
    def __init__(self) -> None: ...

    IsAccurateMass: bool  # readonly
    PeakFinderOptions: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.SpectrumPeakFinderOptions
    )  # readonly
    QuantDataAccess: QuantDataAccess  # readonly
    RecordCount: int  # readonly
    SampleDataPath: str  # readonly

    def GetAbundanceArrayFromScanRecord(
        self, scanNumber: int, firstPointIndex: int, nPoints: int
    ) -> List[float]: ...
    def Open(self, sampleDataPath: str) -> None: ...
    def GetScanTimeForScanRecord(self, scanNumber: int) -> float: ...
    def GetNextScanIndexForSameScanConditions(
        self, scanIndex: int, scanConditions: ScanConditions
    ) -> int: ...
    def GetScanConditionsForScanRecord(self, scanNumber: int) -> ScanConditions: ...
    def GetScanRecordByScanIndex(self, scanNumber: int) -> ScanRecord: ...
    def ExportProfileSpectrum(self, scanNumber: int) -> None: ...
    def CaptureApexSpacingHistogram(self, scanNumber: int) -> None: ...
    def Close(self) -> None: ...
    def ExportProfileSpectra(self, scanNumbers: List[int]) -> None: ...
    def GetApexSpacingHistogram(self, scanRecord: ScanRecord) -> List[int]: ...
    def GetProfileDataForScanRecord(
        self, scanNumber: int, applyMassCal: bool
    ) -> Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.ProfileSpectrum: ...
    def GetPrevScanIndexForSameScanConditions(
        self, scanIndex: int, scanConditions: ScanConditions
    ) -> int: ...

class SpectrumPeakFinderOptions:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, optionsFile: str) -> None: ...

    ApplyMassStepFiltering: bool
    CentroidType: Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.CentroidType
    InterpolationType: (
        Agilent.MassSpectrometry.DataAnalysis.TofDataBrowser.InterpolationType
    )
    ResolveShoulderPeaks: bool
    WriteApexList: bool
    WriteHistogram: bool
    WritePeakShapes: bool



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFilesConsole

class CommandLine(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    CsvFile: str
    Culture: str
    Folders: List[str]
    Help: bool
    NoLogo: bool
    OutFile: str
    Recursive: bool
    TabDelimitedFile: str
    XmlFile: str

    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces

class AcquiredDateCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(
        self,
        dateCondition: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange,
    ) -> None: ...

    AcquiredDateSearchRange: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange
    )  # readonly

class AcquisitionOperatorCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(self, userName: str) -> None: ...

    UserName: str  # readonly

class DateSearchRange:  # Class
    @overload
    def __init__(
        self,
        dateRange: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange,
    ) -> None: ...
    @overload
    def __init__(
        self,
        date: System.DateTime,
        relation: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.DateRelation,
    ) -> None: ...

    Date: Optional[System.DateTime]  # readonly
    DateRange: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
    )  # readonly
    Relation: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.DateRelation
    )  # readonly

    # Nested Types

    class DateRelation(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        After: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.DateRelation
        ) = ...  # static # readonly
        Before: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.DateRelation
        ) = ...  # static # readonly
        Undefined: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.DateRelation
        ) = ...  # static # readonly

    class FixedDateRange(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        LastMonth: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        LastWeek: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        LastYear: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        ThisMonth: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        ThisWeek: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        ThisYear: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        Today: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        Undefined: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly
        Yesterday: (
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange.FixedDateRange
        ) = ...  # static # readonly

class FileNameCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(self, fileNamePattern: str) -> None: ...

    FileNamePattern: str  # readonly

class GenericFileAttributes(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Hidden: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes
    ) = ...  # static # readonly
    ReadOnly: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes
    ) = ...  # static # readonly
    System: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes
    ) = ...  # static # readonly

class GenericFileInfo(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFileInfo
):  # Class
    Attributes: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes
    )  # readonly
    CreationTime: Optional[System.DateTime]  # readonly
    LastModifiedTime: Optional[System.DateTime]  # readonly
    Length: int  # readonly
    Name: str  # readonly
    Path: str  # readonly

    def IsAttributeSet(
        self,
        attributes: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes,
    ) -> bool: ...

class GenericFolderAttributes(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Archived: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    CanBeProjectFolder: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    CanBeStorageFolder: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    CanContainFiles: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    CreateFolderSupported: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    ReadOnly: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly
    Root: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    ) = ...  # static # readonly

class GenericFolderInfo(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
):  # Class
    Attributes: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    )  # readonly
    CreationTime: Optional[System.DateTime]  # readonly
    Name: str  # readonly
    Path: str  # readonly

    def IsAttributeSet(
        self,
        attributes: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes,
    ) -> bool: ...

class GenericPathComparer(System.Collections.Generic.IEqualityComparer[str]):  # Class
    def __init__(
        self,
        pathHelper: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
        caseSensitive: bool,
    ) -> None: ...
    def GetHashCode(self, obj: str) -> int: ...
    def Equals(self, x: str, y: str) -> bool: ...

class IFileVersionInfo(object):  # Interface
    AbsolutePath: str  # readonly
    CheckinComment: str  # readonly
    Created: Optional[System.DateTime]  # readonly
    CreatedBy: str  # readonly
    FileVersion: str  # readonly
    IsCurrentVersion: bool  # readonly
    VersionLabel: str  # readonly

class IGenericFileInfo(object):  # Interface
    Attributes: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes
    )  # readonly
    CreationTime: Optional[System.DateTime]  # readonly
    LastModifiedTime: Optional[System.DateTime]  # readonly
    Length: int  # readonly
    Name: str  # readonly
    Path: str  # readonly

    def IsAttributeSet(
        self,
        attributes: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFileAttributes,
    ) -> bool: ...

class IGenericFolderInfo(object):  # Interface
    Attributes: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes
    )  # readonly
    CreationTime: Optional[System.DateTime]  # readonly
    Name: str  # readonly
    Path: str  # readonly

    def IsAttributeSet(
        self,
        attributes: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.GenericFolderAttributes,
    ) -> bool: ...

class IPathHelper(object):  # Interface
    MaxPathElementLength: int  # readonly
    MaxPathLength: int  # readonly

    def GetRelativePath(self, absolutePath: str, relativeTo: str) -> str: ...
    def GetFileNameWithoutExtension(self, filePath: str) -> str: ...
    def Combine(self, elements: List[str]) -> str: ...
    def Split(self, path: str) -> List[str]: ...
    def GetFileExtension(self, filePath: str) -> str: ...
    def GetDirectoryName(self, path: str) -> str: ...
    def GetFileName(self, filePath: str) -> str: ...
    def IsSubpathOf(self, path: str, subpath: str) -> bool: ...
    def IsPathValid(self, path: str) -> bool: ...
    def GetPathComparer(self) -> System.Collections.Generic.IEqualityComparer[str]: ...
    def GetInvalidPathChars(self) -> List[str]: ...
    def IsPathRooted(self, path: str) -> bool: ...
    def NormalizePath(self, path: str) -> str: ...
    def GetPathWithoutFileName(self, path: str) -> str: ...
    def GetParentFolderName(self, path: str) -> str: ...
    def GetParentFolderPath(self, path: str) -> str: ...
    def GetInvalidFileNameChars(self) -> List[str]: ...

class ISearchCondition(object):  # Interface
    ...

class ISearchParameters(object):  # Interface
    ResultAttributes: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute
    ]  # readonly
    ResultsPerPage: int  # readonly
    SearchQuery: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery
    )  # readonly
    SortAttribute: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute
    )  # readonly
    SortDirection: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchResultSortDirection
    )  # readonly
    StartPage: int  # readonly

class ISearchQuery(object):  # Interface
    SearchConditions: Iterable[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
    ]  # readonly

    def AddSearchConditions(
        self,
        newSearchConditions: Iterable[
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
        ],
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery: ...
    def AddSearchCondition(
        self,
        searchCondition: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition,
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery: ...

class ISearchResult(object):  # Interface
    Path: str  # readonly

    def GetResultsValueAsString(
        self,
        searchAttribute: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute,
    ) -> str: ...
    def GetResultsValue(
        self,
        searchAttribute: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[
            T
        ],
    ) -> T: ...
    def HasResultsValue(
        self,
        searchAttribute: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute,
    ) -> bool: ...

class ISearchResults(object):  # Interface
    HasMoreResults: bool  # readonly
    Results: Iterable[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchResult
    ]  # readonly

class ISearchable(object):  # Interface
    def Search(
        self,
        searchParameters: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchParameters,
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchResults: ...
    def SearchAsync(
        self,
        searchParameters: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchParameters,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchResults
    ]: ...

class IStorageBrowser(object):  # Interface
    RootFolderNames: Iterable[str]  # readonly

    def GetFolderPathNamesAsync(
        self,
        folderPath: str,
        searchPattern: str,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[List[str]]: ...
    def GetFileVersionsAsync(
        self, filePath: str, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[
        List[
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IFileVersionInfo
        ]
    ]: ...
    def GetRootFolder(
        self, path: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...
    def GetFilePathNames(
        self, folderPath: str, searchPattern: str = ...
    ) -> List[str]: ...
    def GetFolderInfos(
        self, folderPath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ]: ...
    def GetFileInfoAsync(
        self, filePath: str, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFileInfo
    ]: ...
    def GetFileInfo(
        self, filePath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFileInfo
    ): ...
    def GetCurrentDirectory(
        self,
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...
    def GetFileVersions(
        self, filePath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IFileVersionInfo
    ]: ...
    def GetFilePathNamesAsync(
        self,
        folderPath: str,
        searchPattern: str,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[List[str]]: ...
    def GetLastestFileVersion(
        self, filePath: str
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo: ...
    def GetFileInfos(
        self, folderPath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFileInfo
    ]: ...
    def GetFolderInfo(
        self, folderPath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...
    @overload
    def GetFileMetaData(self, filePath: str) -> str: ...
    @overload
    def GetFileMetaData(
        self,
        filePath: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> str: ...
    def GetFolderPathNames(
        self, folderPath: str, searchPattern: str = ...
    ) -> List[str]: ...
    def GetParentFolder(
        self, fileOrFolderPath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...

class IStorageCapabilities(object):  # Interface
    SupportsSearch: bool  # readonly
    SupportsVersions: bool  # readonly

class IStorageFileAccess(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper
):  # Interface
    def ExistsAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[bool]: ...
    def IsFolder(self, path: str) -> bool: ...
    def IsFile(self, path: str) -> bool: ...
    @overload
    def OpenFile(self, path: str) -> System.IO.Stream: ...
    @overload
    def OpenFile(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.IO.Stream: ...
    def IsFileAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[bool]: ...
    def IsFolderAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[bool]: ...
    def Exists(self, path: str) -> bool: ...
    @overload
    def OpenFileAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken = ...
    ) -> System.Threading.Tasks.Task[System.IO.Stream]: ...
    @overload
    def OpenFileAsync(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken = ...,
    ) -> System.Threading.Tasks.Task[System.IO.Stream]: ...
    @overload
    def SaveFile(self, path: str, data: System.IO.Stream) -> None: ...
    @overload
    def SaveFile(
        self,
        path: str,
        data: System.IO.Stream,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> None: ...
    def DeleteFile(self, path: str) -> None: ...

class IStorageFileSetAccess(object):  # Interface
    def RemoveFileAsync(
        self, fileSetPath: str, fileNameOrPath: str
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def AddFileAsync(
        self, fileSetPath: str, fileNameOrPath: str
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def AddFileAsync(
        self,
        fileSetPath: str,
        fileNameOrPath: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.Threading.Tasks.Task[None]: ...
    def GetFileVersion(
        self, fileSetPath: str, fileNameOrPath: str
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo: ...
    @overload
    def SetVersionAsync(
        self,
        fileSetPath: str,
        fileNameOrPath: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def SetVersionAsync(
        self,
        fileSetPath: str,
        fileNamesOrPaths: Iterable[str],
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def SetVersionAsync(
        self,
        fileSetPath: str,
        versionMap: Mapping[
            str, Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo
        ],
    ) -> System.Threading.Tasks.Task[None]: ...
    def GetFileVersions(
        self, fileSetPath: str
    ) -> Mapping[
        str, Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo
    ]: ...
    def CreateFileSet(self, fileSetPath: str) -> None: ...
    def BufferedUploadFileSetAsync(
        self,
        fileSetPath: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.Threading.Tasks.Task[None]: ...
    def UploadFileSetAsync(
        self,
        fileSetPath: str,
        version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[None]: ...

class IStorageProvider(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageBrowser,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageRepositoryAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchable,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageCapabilities,
):  # Interface
    DefaultWorkArea: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageWorkAreaAccess
    )  # readonly
    Id: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.StorageType
    )  # readonly

    def CloseWorkArea(self, workAreaName: str) -> None: ...
    @overload
    def GetWorkArea(
        self, workAreaName: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageWorkAreaAccess
    ): ...
    @overload
    def GetWorkArea(
        self, hostname: str, workAreaName: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageWorkAreaAccess
    ): ...
    def IsStorageAvailableAsync(
        self, cancellationToken: System.Threading.CancellationToken
    ) -> System.Threading.Tasks.Task[System.Tuple[bool, str]]: ...

class IStorageRepositoryAccess(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
):  # Interface
    @overload
    def CreateFolder(
        self, folderPath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...
    @overload
    def CreateFolder(
        self, parentFolderPath: str, newFolderName: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ): ...
    @overload
    def OpenFile(self, path: str, workAreaName: str) -> System.IO.Stream: ...
    @overload
    def OpenFile(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        workAreaName: str,
    ) -> System.IO.Stream: ...
    @overload
    def OpenFileAsync(
        self,
        path: str,
        workAreaName: str,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[System.IO.Stream]: ...
    @overload
    def OpenFileAsync(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        workAreaName: str,
        cancellationToken: System.Threading.CancellationToken,
    ) -> System.Threading.Tasks.Task[System.IO.Stream]: ...
    @overload
    def SaveFileBuffered(self, path: str, data: System.IO.Stream) -> None: ...
    @overload
    def SaveFileBuffered(
        self, path: str, data: System.IO.Stream, workAreaName: str
    ) -> None: ...
    @overload
    def SaveFileBuffered(
        self,
        path: str,
        data: System.IO.Stream,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> None: ...
    @overload
    def SaveFileBuffered(
        self,
        path: str,
        data: System.IO.Stream,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        workAreaName: str,
    ) -> None: ...
    @overload
    def SaveFile(
        self, path: str, data: System.IO.Stream, workAreaName: str
    ) -> None: ...
    @overload
    def SaveFile(
        self,
        path: str,
        data: System.IO.Stream,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        workAreaName: str,
    ) -> None: ...
    def CreateFolderAsync(
        self,
        folderPath: str,
        cancellationToken: System.Threading.CancellationToken = ...,
    ) -> System.Threading.Tasks.Task[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
    ]: ...
    def DeleteFolder(self, folderPath: str) -> None: ...

class IStorageRepositoryTransfer(object):  # Interface
    @overload
    def DownloadFile(self, path: str) -> None: ...
    @overload
    def DownloadFile(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> None: ...
    @overload
    def UploadFileAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken = ...
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def UploadFileAsync(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken = ...,
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def DownloadFileAsync(
        self, path: str, cancellationToken: System.Threading.CancellationToken = ...
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def DownloadFileAsync(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
        cancellationToken: System.Threading.CancellationToken = ...,
    ) -> System.Threading.Tasks.Task[None]: ...
    def RequiresUpload(self, path: str) -> bool: ...
    @overload
    def UploadFileBufferedAsync(
        self, path: str
    ) -> System.Threading.Tasks.Task[None]: ...
    @overload
    def UploadFileBufferedAsync(
        self,
        path: str,
        versionInfo: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo,
    ) -> System.Threading.Tasks.Task[None]: ...

class IStorageWorkAreaAccess(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileSetAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageRepositoryTransfer,
):  # Interface
    Name: str  # readonly

    @overload
    def ExportFile(self, sourcePath: str) -> str: ...
    @overload
    def ExportFile(self, sourcePath: str, targetPath: str) -> None: ...
    def GetFiles(self, folderPath: str) -> Iterable[str]: ...
    def CopyFile(self, sourcePath: str, targetPath: str) -> None: ...
    def GetHashValue(self, filePath: str) -> str: ...
    def CreateFile(self, path: str) -> System.IO.Stream: ...
    def MoveFile(self, sourcePath: str, targetPath: str) -> None: ...
    def OpenWrite(self, path: str) -> System.IO.Stream: ...
    def ImportFile(self, sourcePath: str, targetPath: str) -> None: ...
    def GetFolders(self, folderPath: str) -> Iterable[str]: ...

class ITransferProcess(System.IAsyncResult):  # Interface
    IsCanceled: bool  # readonly
    PercentOfProgress: int  # readonly

class IVersionStorageProvider(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageProvider,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageBrowser,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageRepositoryAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageFileAccess,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IPathHelper,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchable,
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IStorageCapabilities,
):  # Interface
    def GetVersionedFileInfo(
        self, filePath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IVersionedFileInfo
    ): ...
    @overload
    def GetFileHistory(
        self, filePath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IFileVersionInfo
    ]: ...
    @overload
    def GetFileHistory(
        self, filePath: str, versionLabel: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IFileVersionInfo
    ]: ...
    def GetVersionedFolderInfos(
        self, folderPath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IVersionedFolderInfo
    ]: ...
    def GetVersionedFileInfos(
        self, folderPath: str
    ) -> List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IVersionedFileInfo
    ]: ...
    def GetVersionedFolderInfo(
        self, folderPath: str
    ) -> (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IVersionedFolderInfo
    ): ...

class IVersionedFileInfo(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFileInfo
):  # Interface
    CheckoutBy: str  # readonly
    StateAttributes: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionedState
    )  # readonly
    VersionLabel: str  # readonly

class IVersionedFolderInfo(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.IGenericFolderInfo
):  # Interface
    CreatedBy: str  # readonly
    LastModifiedBy: str  # readonly

class LastProcessedDateCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(
        self,
        dateSearchRange: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange,
    ) -> None: ...

    LastProcessedDateSearchRange: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.DateSearchRange
    )  # readonly

class MethodContentType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Unknown: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.MethodContentType
    ) = ...  # static # readonly

class MethodStatusType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Draft: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.MethodStatusType
    ) = ...  # static # readonly
    Final: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.MethodStatusType
    ) = ...  # static # readonly
    Reviewed: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.MethodStatusType
    ) = ...  # static # readonly

class PathCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(self, path: str) -> None: ...

    Path: str  # readonly

class ResultContentType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Sequence: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ResultContentType
    ) = ...  # static # readonly
    SingleSample: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ResultContentType
    ) = ...  # static # readonly
    Undefined: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ResultContentType
    ) = ...  # static # readonly

class SaveOptions:  # Class
    def __init__(self) -> None: ...

    Reason: str
    UploadMode: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.UploadMode
    Version: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionInfo
    WorkAreaName: str

class SearchAttribute:  # Class
    Name: str  # readonly

class SearchAttribute(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute,
    Generic[T],
):  # Class
    def __init__(self, name: str) -> None: ...

    SearchAttributeType: System.Type  # readonly

class SearchAttributes:  # Class
    AcquisitionInstrument: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly
    AcquisitionOperator: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly
    AcquisitionTime: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[
            System.DateTime
        ]
    )  # static # readonly
    FileName: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly
    FilePath: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly
    ResultContentType: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ResultContentType
    ]  # static # readonly
    SampleName: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly
    SequenceName: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute[str]
    )  # static # readonly

class SearchParameters(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchParameters
):  # Class
    @overload
    def __init__(
        self,
        resultsPerPage: int,
        searchQuery: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery,
        startPage: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        resultsPerPage: int,
        searchQuery: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery,
        startPage: int,
        resultAttributes: System.Collections.Generic.List[
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute
        ],
        sortAttribute: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute,
        sortDirection: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchResultSortDirection,
    ) -> None: ...

    ResultAttributes: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute
    ]
    ResultsPerPage: int
    SearchQuery: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery
    )
    SortAttribute: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchAttribute
    )
    SortDirection: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchResultSortDirection
    )
    StartPage: int

class SearchQuery(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery
):  # Class
    def __init__(self) -> None: ...

    SearchConditions: Iterable[
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
    ]  # readonly

    def AddSearchConditions(
        self,
        newSearchConditions: Iterable[
            Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
        ],
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery: ...
    def AddSearchCondition(
        self,
        searchCondition: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition,
    ) -> Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchQuery: ...

class SearchResultSortDirection(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Ascending: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchResultSortDirection
    ) = ...  # static # readonly
    Descending: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.SearchResultSortDirection
    ) = ...  # static # readonly

class StorageType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DataStore: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.StorageType
    ) = ...  # static # readonly
    Local: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.StorageType = (
        ...
    )  # static # readonly
    Unsupported: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.StorageType
    ) = ...  # static # readonly

class UploadMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Buffered: Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.UploadMode = (
        ...
    )  # static # readonly
    Immediate: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.UploadMode
    ) = ...  # static # readonly

class VerbatimCondition(
    Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.ISearchCondition
):  # Class
    def __init__(self, queryText: str) -> None: ...

    QueryText: str  # readonly

class VersionInfo:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, label: str) -> None: ...
    @overload
    def __init__(self, label: str, timestamp: System.DateTime) -> None: ...
    @overload
    def __init__(self, timestamp: System.DateTime) -> None: ...

    VersionLabel: str  # readonly

class VersionedState(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CheckedOut: (
        Agilent.OpenLab.Framework.Infrastructure.Storage.Interfaces.VersionedState
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ToolDefinitions.Properties

class Resources:  # Class
    AddSamples_Label: str  # static # readonly
    AddSamples_Title: str  # static # readonly
    AppendMethod_Label: str  # static # readonly
    AppendMethod_Title: str  # static # readonly
    AuditTrail_GenerateReport: str  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    ErrMsg_BatchFileDoesNotExist: str  # static # readonly
    ErrMsg_CannotFindTuneEval: str  # static # readonly
    ErrMsg_CannotPlotThisColumn: str  # static # readonly
    ErrMsg_EnterMethod: str  # static # readonly
    ErrMsg_LibraryMethodDoesNotExist: str  # static # readonly
    ErrMsg_MethodNotExist: str  # static # readonly
    ErrMsg_NoPermissionToGenerateReport: str  # static # readonly
    ErrMsg_PleaseEnterInteger: str  # static # readonly
    ErrMsg_PleaseEnterNumber: str  # static # readonly
    ErrMsg_PleaseEnterSamplePath: str  # static # readonly
    ErrMsg_PleaseEnterValueToColumn: str  # static # readonly
    ErrMsg_PleaseSelectOneSample: str  # static # readonly
    ErrMsg_ReportError: str  # static # readonly
    ErrMsg_SampleDoesNotExist: str  # static # readonly
    ErrMsg_TranslatorNotInstalled: str  # static # readonly
    ErrMsg_UnknownsFileType: str  # static # readonly
    Err_PleaseEnterFloatingNumberValue: str  # static # readonly
    Exp_CannotAddSample_AcquisitionNotFinished: str  # static # readonly
    Exp_CannotAddSample_FailedToReadFile: str  # static # readonly
    Exp_CannotAddSample_FileNotFound: str  # static # readonly
    FileType_TextFiles: str  # static # readonly
    FindOperatorType_Contains: str  # static # readonly
    FindOperatorType_Equal: str  # static # readonly
    FindOperatorType_Greater: str  # static # readonly
    FindOperatorType_GreaterEqual: str  # static # readonly
    FindOperatorType_IsNull: str  # static # readonly
    FindOperatorType_Less: str  # static # readonly
    FindOperatorType_LessEqual: str  # static # readonly
    FindOperatorType_NotContains: str  # static # readonly
    FindOperatorType_NotEqual: str  # static # readonly
    FindOperatorType_NotNull: str  # static # readonly
    GotoUnknowns_Message: str  # static # readonly
    GotoUnknowns_Title: str  # static # readonly
    Label_AllFiles: str  # static # readonly
    Label_CEFFiles: str  # static # readonly
    Label_CSVFiles: str  # static # readonly
    Label_CompoundID: str  # static # readonly
    Label_ExcelFiles: str  # static # readonly
    Label_LibraryFiles: str  # static # readonly
    Label_LibraryMethodDeconvolution: str  # static # readonly
    Label_MethodFiles: str  # static # readonly
    Label_NumCalibrationSamplesSelected: str  # static # readonly
    Label_NumTargetCompoundsSelected: str  # static # readonly
    Label_OpenReportFile: str  # static # readonly
    Label_PdfFiles: str  # static # readonly
    Label_RTCalibrationFiles: str  # static # readonly
    Label_RecentReportMethods: str  # static # readonly
    Label_ReferenceLibraryFiles: str  # static # readonly
    Label_ReportTemplateFiles: str  # static # readonly
    Label_SelectCompounds: str  # static # readonly
    Label_SelectSamples: str  # static # readonly
    Label_TabDelimitedFiles: str  # static # readonly
    Label_TextFiles: str  # static # readonly
    Label_XmlFiles: str  # static # readonly
    ListItem_Origin: str  # static # readonly
    MSScanType_All: str  # static # readonly
    MSScanType_MultipleReaction: str  # static # readonly
    MSScanType_Scan: str  # static # readonly
    MSScanType_SelectedIon: str  # static # readonly
    MethodFromLibraryIonMode_HighestMass: str  # static # readonly
    MethodFromLibraryIonMode_Monoisotopic: str  # static # readonly
    MethodFromLibraryIonMode_MostAbundant: str  # static # readonly
    MethodFromLibraryIonMode_Weighted: str  # static # readonly
    Msg_AnalyzeBeforeGenerateReport: str  # static # readonly
    Msg_CannotEditMethodOfSkippedSample: str  # static # readonly
    Msg_CannotFindMethodReportTemplate: str  # static # readonly
    Msg_CannotFindTheDataSearchingFor: str  # static # readonly
    Msg_EnterExpectedConcentrationToAddCalibration: str  # static # readonly
    Msg_ExportingTable: str  # static # readonly
    Msg_GeneratingReportsPleaseWait: str  # static # readonly
    Msg_InputValidNumber: str  # static # readonly
    Msg_MethodCreated: str  # static # readonly
    Msg_ProcessingSample: str  # static # readonly
    Msg_ReferencePatternLibraryGenerated: str  # static # readonly
    Msg_ReportCanceled: str  # static # readonly
    Msg_SaveBatchBeforeAnalyzeUnknowns: str  # static # readonly
    Msg_SaveBatchBeforeReport: str  # static # readonly
    Msg_SelectASample: str  # static # readonly
    Msg_SelectCompounds: str  # static # readonly
    Msg_SelectLevels: str  # static # readonly
    Msg_SelectSamples: str  # static # readonly
    NewMethod_Label: str  # static # readonly
    NewMethod_Title: str  # static # readonly
    OpenMethod_Label: str  # static # readonly
    OpenMethod_Title: str  # static # readonly
    Progress_AddingCompound: str  # static # readonly
    Progress_CreatingXtensIonTargets: str  # static # readonly
    Progress_SetupReferencePatternLibrary: str  # static # readonly
    Prompt_EmptyMolecularFormula_Continue: str  # static # readonly
    Prompt_QualNotFound_Specify: str  # static # readonly
    Prompt_QualifierRatioNotUpdatedNoPeakFound: str  # static # readonly
    Prompt_SamplesAlreadyExistsContinue: str  # static # readonly
    Prompt_SaveBatchBeforeGotoUnknowns: str  # static # readonly
    Prompt_SaveBatchBeforeReport: str  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    SampleGroup_All: str  # static # readonly
    SampleGroup_Tooltip: str  # static # readonly
    SampleGroup_Unassigned: str  # static # readonly
    SampleType_All: str  # static # readonly
    SampleType_Tooltip: str  # static # readonly
    SampleType_Unassigned: str  # static # readonly
    Sample_Tooltip: str  # static # readonly
    SignalType_All: str  # static # readonly
    SignalType_None: str  # static # readonly
    Title_AddCalibration: str  # static # readonly
    Title_AppendMethodFromAcquiredData: str  # static # readonly
    Title_AppendMethodFromAcquiredScanData: str  # static # readonly
    Title_AppendMethodFromAcquiredScanDataWithLibrarySearch: str  # static # readonly
    Title_AppendMethodFromFile: str  # static # readonly
    Title_AverageCalibration: str  # static # readonly
    Title_AverageCalibrationReplicates: str  # static # readonly
    Title_AverageQualifierRatios: str  # static # readonly
    Title_AverageRetentionTime: str  # static # readonly
    Title_ClearCalibration: str  # static # readonly
    Title_CopyCalibrationLevelsTo: str  # static # readonly
    Title_CreateXtensIonTargets: str  # static # readonly
    Title_DisableCalibrationPoints: str  # static # readonly
    Title_ExportTable: str  # static # readonly
    Title_ImportLevelsFromFile: str  # static # readonly
    Title_LoadLayout: str  # static # readonly
    Title_NewMethodFromAcquiredData: str  # static # readonly
    Title_NewMethodFromAcquiredScanData: str  # static # readonly
    Title_NewMethodFromAcquiredScanDataWithLibrarySearch: str  # static # readonly
    Title_NewMethodFromFile: str  # static # readonly
    Title_OpenCEFFile: str  # static # readonly
    Title_OpenMethod: str  # static # readonly
    Title_OpenMethodFromExistingBatch: str  # static # readonly
    Title_RemoveCalibration: str  # static # readonly
    Title_ReplaceCalibration: str  # static # readonly
    Title_SaveLayout: str  # static # readonly
    Title_ScanAnalysisParameters: str  # static # readonly
    Title_ShiftRetentionTime: str  # static # readonly
    Title_UpdateMassAssignments: str  # static # readonly
    Title_UpdateQualifierRatios: str  # static # readonly
    Title_UpdateRetentionTime: str  # static # readonly
    Title_UpdateRetentionTimeFromISTD: str  # static # readonly
    ToolLabel_AllColumnsAreVisible: str  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing

class HeaderFooterBitmap(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterElementBase
):  # Class
    def __init__(self) -> None: ...

    File: str

    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        rc: System.Drawing.Rectangle,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterParameters,
    ) -> System.Drawing.Size: ...

class HeaderFooterDefinition:  # Class
    def __init__(self) -> None: ...

    Footer: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterRegion
    )
    Header: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterRegion
    )

    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        margin: System.Drawing.Rectangle,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterParameters,
    ) -> System.Drawing.Rectangle: ...

class HeaderFooterElementBase:  # Class
    def __init__(self) -> None: ...

    Height: str
    HorizontalAlignment: System.Windows.Forms.HorizontalAlignment

    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        rc: System.Drawing.Rectangle,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterParameters,
    ) -> System.Drawing.Size: ...

class HeaderFooterParameters:  # Class
    def __init__(self) -> None: ...
    def Replace(self, value_: str) -> str: ...
    def SetStringMap(self, key: str, value_: Any) -> None: ...

class HeaderFooterRegion:  # Class
    def __init__(self) -> None: ...

    Elements: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterElementBase
    ]
    Height: str

    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        rect: System.Drawing.Rectangle,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterParameters,
    ) -> None: ...
    def GetHeightInPixel(self, graphics: System.Drawing.Graphics) -> int: ...

class HeaderFooterTextBox(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterElementBase
):  # Class
    def __init__(self) -> None: ...

    FontFamily: str
    FontSize: float
    FontStyle: System.Drawing.FontStyle
    Format: str
    Text: str

    def Draw(
        self,
        graphics: System.Drawing.Graphics,
        rc: System.Drawing.Rectangle,
        parameters: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.Printing.HeaderFooterParameters,
    ) -> System.Drawing.Size: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    BatchFiles,
    IOutlier,
    OutlierColumns,
    OutlierCompoundType,
    OutlierFilterType,
    QuantitationDataSet,
)

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FlagAndFilter

class FlagFilterManager(
    System.IDisposable, Agilent.MassHunter.Quantitative.UIModel.IFlagFilterManager
):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    Filter: bool
    FilterType: OutlierFilterType
    Flag: bool
    def __getitem__(
        self, index: int
    ) -> Agilent.MassHunter.Quantitative.UIModel.IFlagFilter: ...
    def __getitem__(
        self, column: OutlierColumns
    ) -> Agilent.MassHunter.Quantitative.UIModel.IFlagFilter: ...
    def RemoveAt(self, index: int) -> None: ...
    def SampleFilterMatch(
        self,
        sampleRow: QuantitationDataSet.BatchRow,
        compoundKeys: List[Agilent.MassHunter.Quantitative.UIModel.CompoundKey],
    ) -> bool: ...
    def Initialize(
        self, state: Agilent.MassHunter.Quantitative.UIModel.IPresentationState
    ) -> None: ...
    def Add(
        self,
        ff: Agilent.MassSpectrometry.DataAnalysis.Quantitative.FlagAndFilter.IFlagFilter,
    ) -> None: ...
    def SummaryMatch(
        self,
        sampleRow: QuantitationDataSet.BatchRow,
        compoundKeys: List[Agilent.MassHunter.Quantitative.UIModel.CompoundKey],
        messages: System.Text.StringBuilder,
    ) -> bool: ...
    def EndEdit(self) -> None: ...
    def BeginEdit(self) -> None: ...
    def CompoundFilterMatch(
        self,
        compoundRow: QuantitationDataSet.TargetCompoundRow,
        sampleRows: List[System.Data.DataRow],
    ) -> bool: ...
    def Dispose(self) -> None: ...
    def FlagMatch(
        self,
        relation: str,
        column: str,
        parentRow: System.Data.DataRow,
        row: System.Data.DataRow,
        backColor: System.Drawing.Color,
        foreColor: System.Drawing.Color,
        messages: System.Text.StringBuilder,
    ) -> bool: ...

    Changed: System.EventHandler  # Event

class IFlagFilter(Agilent.MassHunter.Quantitative.UIModel.IFlagFilter):  # Interface
    ...

class OutlierFlagFilter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.FlagAndFilter.IFlagFilter,
    Agilent.MassHunter.Quantitative.UIModel.IFlagFilter,
):  # Class
    def __init__(self) -> None: ...

    Category: str  # readonly
    ColumnName: str  # readonly
    Enabled: bool
    Name: str  # readonly
    OutlierCompoundType: OutlierCompoundType  # readonly
    OutlierType: OutlierColumns  # readonly
    OutlierValueColumnName: str  # readonly
    OutlierValueRelationName: str  # readonly
    RelationName: str  # readonly

    def Available(
        self, dataset: System.Data.DataSet, batchFiles: BatchFiles, batchId: int
    ) -> bool: ...
    def Initialize(self, outlier: IOutlier) -> None: ...
    def GetMessage(self, row: System.Data.DataRow) -> str: ...
    @staticmethod
    def IsOutlierAvailable(
        dataset: System.Data.DataSet,
        batchFiles: BatchFiles,
        batchId: int,
        outlierColumn: OutlierColumns,
    ) -> bool: ...
    @staticmethod
    def UpdateColors() -> None: ...
    def Match(
        self,
        row: System.Data.DataRow,
        type: OutlierFilterType,
        backColor: System.Drawing.Color,
        foreColor: System.Drawing.Color,
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.UnknownsAnalysis.ComponentsAtAGlance

class GridPlotContent(
    System.Windows.Controls.Primitives.IScrollInfo,
    Agilent.MassHunter.Quantitative.PlotControl.GridPlotContent,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def DrawPane(
        self,
        drawingContext: System.Windows.Media.DrawingContext,
        rect: System.Windows.Rect,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        dataSource: Any,
    ) -> None: ...
    def Initialize(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
    ) -> None: ...
    def AutoScaleLinedAxesX(self) -> None: ...
    def GetAutoScaleRange(
        self,
        pane: Agilent.MassHunter.Quantitative.PlotControl.GridPlotPane,
        vertical: bool,
    ) -> Agilent.MassHunter.Quantitative.PlotControl.Range: ...
    def Uninitialize(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...

    GridPlotContent: (
        Agilent.MassHunter.UnknownsAnalysis.ComponentsAtAGlance.GridPlotContent
    )  # readonly

    def Initialize(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...

class PlotData(
    List[Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries],
    Iterable[Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries],
    Sequence[Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries],
    Iterable[Any],
    Sequence[Any],
    List[Any],
    System.Collections.Generic.List[
        Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries
    ],
):  # Class
    def __init__(
        self,
        chid: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ComponentHitID,
    ) -> None: ...

    Initialized: bool  # readonly
    Title: str  # readonly

    def InitializeChromatogram(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
        brushes: List[System.Windows.Media.Brush],
    ) -> None: ...
    def InitializeSpectrum(
        self,
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
        brushes: List[System.Windows.Media.Brush],
    ) -> None: ...

class PlotSeries(
    Agilent.MassHunter.Quantitative.PlotControl.IPlotSeries,
    Agilent.MassHunter.Quantitative.PlotControl.IPeaks,
):  # Class
    def __init__(
        self, xarr: List[float], yarr: List[float], spectrum: bool
    ) -> None: ...

    Count: int  # readonly
    IsSpectrum: bool  # readonly
    PeakCount: int  # readonly
    PeakLabelFormat: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.INumericCustomFormat
    )
    PeakLabelsVisible: bool  # readonly
    Pen: System.Windows.Media.Pen
    PlotMode: Agilent.MassHunter.Quantitative.PlotControl.PlotMode  # readonly
    Title: str
    Visible: bool

    def GetPeakBaselinePen(self, index: int) -> System.Windows.Media.Pen: ...
    def GetPeakLabel(self, index: int) -> str: ...
    def GetPeak(self, index: int) -> System.Windows.Point: ...
    def GetPoint(self, index: int, x: float, y: float) -> None: ...
    def GetPeakLabelBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetPeakFillBrush(self, index: int) -> System.Windows.Media.Brush: ...
    def GetBaseline(
        self, index: int, start: System.Windows.Point, end: System.Windows.Point
    ) -> None: ...

class ToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self,
        ribbon: Infragistics.Windows.Ribbon.XamRibbon,
        uiContext: Agilent.MassHunter.UnknownsAnalysis.ComponentsAtAGlance.UIContext,
    ) -> None: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def SetToolState(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState
    ) -> None: ...
    def Execute(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.ToolState.IToolState
    ) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...

class UIContext:  # Class
    def __init__(
        self,
        mainWindow: Agilent.MassHunter.UnknownsAnalysis.ComponentsAtAGlance.MainWindow,
    ) -> None: ...

    MainWindow: (
        Agilent.MassHunter.UnknownsAnalysis.ComponentsAtAGlance.MainWindow
    )  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Context

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands

class CancelNewCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class CommandBase(
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
    Agilent.MassSpectrometry.CommandModel.CommandBase,
):  # Class
    Context: Context  # readonly

class CommitNewCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class CompositeCommandBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    Count: int  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...

class Delete(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CompositeCommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def DeleteNewCompoundColumn(self, columnName: str) -> None: ...
    def DeleteNewCompound(self) -> None: ...
    def DeleteCompound(self, compoundName: str) -> None: ...
    def GetParameters(self) -> List[Any]: ...
    def DeleteColumn(self, compoundName: str, columnName: str) -> None: ...

class DeleteCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context, compoundName: str) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class NewFile(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class OpenFile(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context, file: str, readOnly: bool) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class Paste(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CompositeCommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def StartNewCompound(self) -> None: ...
    def SetNewCompoundColumn(self, name: str, value_: Any) -> None: ...
    def SetCompoundColumn(self, compoundName: str, name: str, value_: Any) -> None: ...
    def GetParameters(self) -> List[Any]: ...
    def CommitNewCompound(self) -> None: ...

class SaveFile(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SaveFileAs(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context, file: str) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetCompoundColumn(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self, context: Context, compoundName: str, name: str, value_: Any
    ) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetNewCompoundColumn(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context, name: str, value_: Any) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetSampleColumn(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self, context: Context, sampleName: str, name: str, value_: Any
    ) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class StartNewCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportFixedGraphics.Commands.CommandBase,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(self, context: Context, name: str, value_: Any) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    DesiredMSStorageType,
    DoubleParameterLimit,
    IAcqMetaData,
    IActuals,
    IBDADataAccess,
    IBDAFileInformation,
    IBdaMsScanRecordCollection,
    IChromatogram,
    IDataAccess,
    IPSetDeviceDelayInfo,
    IPSetExcludeMass,
    IPSetExtractChrom,
    IPSetExtractSpectrum,
    IPSetPeakID,
    IPSetPeakSpectrumExtraction,
    IPSetPrecision,
    IPSetRangeCollection,
    IPSetTofCalibration,
    IPSetUnits,
    IRange,
    IReadChromatogram,
    IReadSpectra,
    ISample,
    ISpectrum,
    IUserCalibration,
    MSScanType,
    RangeCollection,
    SampleCategory,
    SpecType,
)
from .FD import (
    Feature,
    FeatureDetectionCompleted,
    FeatureDetectionParams,
    FeatureDetectionStarted,
    IFeatureSet,
    IFeatureSetQuery,
    IRidgeSet,
    ISampleFeatures,
    ISampleRidges,
    IScanSpace,
    Ridge,
    RidgeDetectionCancelled,
    RidgeDetectionCompleted,
    RidgeDetectionParams,
    RidgeDetectionStarted,
    RidgeDetectionStepDone,
    RidgeDetector,
    SampleFeatureDetector,
    ScanConditions,
)
from .Quantitative import INumericFormat
from .Quantitative.IndexedData import NonMSDataPoint

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess

class DefaultNumericFormat(INumericFormat):  # Class
    def __init__(self) -> None: ...

class FeatureFile(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    IsOpen: bool  # readonly
    IsReadOnly: bool  # readonly
    Version: int  # readonly

    def Read(
        self,
        fdParams: FeatureDetectionParams,
        sampleRidges: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleRidges,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures: ...
    def Write(
        self,
        sf: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures,
        sampleDataPath: str,
    ) -> None: ...
    def Open(self, sampleDataPath: str, readOnly: bool) -> None: ...
    @staticmethod
    def GetFeatureFilePath(sampleDataPath: str) -> str: ...
    def DebugWriteSaturatedFeatures(
        self, sf: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures
    ) -> None: ...
    def Close(self) -> None: ...
    @staticmethod
    def Exists(sampleDataPath: str) -> bool: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def ExistsAndIsUpToDate(sampleDataPath: str) -> bool: ...

class FeatureSet(IFeatureSetQuery, IFeatureSet):  # Class
    @overload
    def __init__(
        self, scanSpace: IScanSpace, fdParams: FeatureDetectionParams, readOnly: bool
    ) -> None: ...
    @overload
    def __init__(
        self,
        scanSpace: IScanSpace,
        fdParams: FeatureDetectionParams,
        version: int,
        readOnly: bool,
    ) -> None: ...

    Count: int  # readonly
    FeatureDetectionParams: FeatureDetectionParams  # readonly
    SaturatedCount: int  # readonly
    ScanSpace: IScanSpace  # readonly

    @overload
    def GetFeatures(self) -> System.Collections.Generic.List[Feature]: ...
    @overload
    def GetFeatures(
        self, rtStart: float, rtEnd: float
    ) -> System.Collections.Generic.List[Feature]: ...
    @overload
    def GetFeatures(
        self, startScanIndex: int, endScanIndex: int
    ) -> System.Collections.Generic.List[Feature]: ...
    def GetCoelutingFeatures(
        self, apexScanIndex: int
    ) -> System.Collections.Generic.List[Feature]: ...
    def Add(self, f: Feature) -> None: ...
    def DebugWriteProtoComponents(self) -> None: ...
    @overload
    def GetFeaturesInRange(
        self, rtStart: float, rtEnd: float, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[Feature]: ...
    @overload
    def GetFeaturesInRange(
        self, minScanIndex: int, maxScanIndex: int, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[Feature]: ...
    def GetFeatureByID(self, featureID: int) -> Feature: ...
    def DebugWriteSaturatedFeatures(self, sw: System.IO.StreamWriter) -> None: ...
    def ReadFeatures(self, br: System.IO.BinaryReader) -> None: ...
    def GetFeaturesInFlightTimeRange(
        self, rtStart: float, rtEnd: float, lowFlightTime: float, highFlightTime: float
    ) -> System.Collections.Generic.List[Feature]: ...
    def WriteFeatures(self, bw: System.IO.BinaryWriter) -> None: ...
    def GetFeaturesInRidge(
        self, ridge: Ridge
    ) -> System.Collections.Generic.List[Feature]: ...
    def GetFeaturesInMzRange(
        self, mzLow: float, mzHigh: float
    ) -> System.Collections.Generic.List[Feature]: ...

class ITofDataConversion(object):  # Interface
    def ConvertToTDAFormat(self, dataPath: str) -> None: ...
    def FeatureDataExistsForSample(self, sampleDataPath: str) -> bool: ...
    def IsSampleTDAConvertible(self, sampleDataPath: str) -> bool: ...
    def CanDetectFeaturesForSample(self, sampleDataPath: str) -> bool: ...
    def IsSampleTDAConverted(self, sampleDataPath: str) -> bool: ...
    def DetectFeatures(self, dataPath: str) -> None: ...
    def RemoveFeatureData(self, dataPath: str) -> None: ...
    def RemoveTDA(self, dataPath: str) -> None: ...

    FeatureDetectionCompleted: FeatureDetectionCompleted  # Event
    FeatureDetectionStarted: FeatureDetectionStarted  # Event
    RidgeDetectionCancelled: RidgeDetectionCancelled  # Event
    RidgeDetectionCompleted: RidgeDetectionCompleted  # Event
    RidgeDetectionStarted: RidgeDetectionStarted  # Event
    RidgeDetectionStepDone: RidgeDetectionStepDone  # Event

class RidgeFile(System.IDisposable):  # Class
    def __init__(self) -> None: ...

    FilePath: str  # readonly
    IsOpen: bool  # readonly
    IsReadOnly: bool  # readonly
    Version: int  # readonly

    def Read(
        self, rdParams: RidgeDetectionParams
    ) -> Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleRidges: ...
    def Write(
        self,
        ridges: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleRidges,
        sampleDataPath: str,
    ) -> None: ...
    def Open(self, sampleDataPath: str, readOnly: bool) -> None: ...
    def Close(self) -> None: ...
    @staticmethod
    def GetRidgeFilePath(sampleDataPath: str) -> str: ...
    @staticmethod
    def Exists(sampleDataPath: str) -> bool: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def ExistsAndIsUpToDate(sampleDataPath: str) -> bool: ...

class RidgeSet(IRidgeSet):  # Class
    @overload
    def __init__(self, rd: RidgeDetector) -> None: ...
    @overload
    def __init__(
        self, scanSpace: IScanSpace, rdParams: RidgeDetectionParams
    ) -> None: ...

    Count: int  # readonly
    NoiseFactor2: float  # readonly
    RidgeDetectionParams: RidgeDetectionParams  # readonly
    RidgeList: System.Collections.Generic.List[Ridge]  # readonly
    SaturationLimit: float  # readonly
    ScanSpace: IScanSpace  # readonly

    def Add(self, ridge: Ridge) -> None: ...
    def ReadRidges(self, br: System.IO.BinaryReader, version: int) -> None: ...
    def GetRidge(self, scanIndex: int, flightTime: float) -> Ridge: ...
    def GetRidgeByID(self, ridgeId: int) -> Ridge: ...
    @overload
    def GetRidgesInRange(
        self, rtMin: float, rtMax: float, mzMin: float, mzMax: float
    ) -> System.Collections.Generic.List[Ridge]: ...
    @overload
    def GetRidgesInRange(
        self, minScanIndex: int, maxScanIndex: int, mzMin: float, mzMax: float
    ) -> System.Collections.Generic.List[Ridge]: ...
    def WriteRidges(self, bw: System.IO.BinaryWriter) -> None: ...

class SampleFeatures(ISampleFeatures):  # Class
    def __init__(self) -> None: ...

    ScanConditionCount: int  # readonly
    ScanConditionList: System.Collections.Generic.List[ScanConditions]  # readonly

    def GetFeatureSet(self, scanConditions: ScanConditions) -> IFeatureSet: ...
    def GetScanSpace(self, scanConditions: ScanConditions) -> IScanSpace: ...
    def CreateFeatureSet(
        self, scanSpace: IScanSpace, fdParams: FeatureDetectionParams
    ) -> IFeatureSet: ...
    def GetWritableFeatureSet(self, scanConditions: ScanConditions) -> IFeatureSet: ...
    def GetFeatureSets(self) -> System.Collections.Generic.List[IFeatureSet]: ...
    def GetFeatureSetForMassCalibration(
        self, scanConditions: ScanConditions
    ) -> IFeatureSet: ...
    def AddFeatureSet(self, scanSpace: IScanSpace, featureSet: IFeatureSet) -> None: ...

class SampleRidges(ISampleRidges):  # Class
    def __init__(self) -> None: ...

    ScanConditionCount: int  # readonly
    ScanConditionList: System.Collections.Generic.List[ScanConditions]  # readonly

    def AddRidgeSet(self, scanSpace: IScanSpace, ridgeSet: IRidgeSet) -> None: ...
    def GetScanSpace(self, scanConditions: ScanConditions) -> IScanSpace: ...
    def GetRidgeSets(self) -> System.Collections.Generic.List[IRidgeSet]: ...
    def GetRidgeSet(self, scanConditions: ScanConditions) -> IRidgeSet: ...
    def AddDetectedRidgeSet(self, rd: RidgeDetector) -> None: ...

class TofDataConversion(
    Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.ITofDataConversion
):  # Class
    def ConvertToTDAFormat(self, dataPath: str) -> None: ...
    def FeatureDataExistsForSample(self, sampleDataPath: str) -> bool: ...
    def IsSampleTDAConvertible(self, sampleDataPath: str) -> bool: ...
    def CanDetectFeaturesForSample(self, sampleDataPath: str) -> bool: ...
    def IsSampleTDAConverted(self, sampleDataPath: str) -> bool: ...
    def DetectFeatures(self, dataPath: str) -> None: ...
    def RemoveFeatureData(self, dataPath: str) -> None: ...
    def RemoveTDA(self, dataPath: str) -> None: ...

    FeatureDetectionCompleted: FeatureDetectionCompleted  # Event
    FeatureDetectionStarted: FeatureDetectionStarted  # Event
    RidgeDetectionCancelled: RidgeDetectionCancelled  # Event
    RidgeDetectionCompleted: RidgeDetectionCompleted  # Event
    RidgeDetectionStarted: RidgeDetectionStarted  # Event
    RidgeDetectionStepDone: RidgeDetectionStepDone  # Event

class TofFeatureDataAccess(
    ISample,
    IActuals,
    IDataAccess,
    IReadChromatogram,
    System.IDisposable,
    IReadSpectra,
    IUserCalibration,
):  # Class
    AcquisitionMetaData: IAcqMetaData  # readonly
    BaseDataAccess: IBDADataAccess  # readonly
    DataFileName: str  # readonly
    DataUnit: IPSetUnits  # readonly
    DesiredMSStorageTypeToUse: DesiredMSStorageType
    FallbackDA: IDataAccess  # readonly
    FeatureFile: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.FeatureFile
    )  # readonly
    FileInformation: IBDAFileInformation  # readonly
    MassRangesOverallLimit: DoubleParameterLimit  # readonly
    MostRecentlyUsed: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.TofFeatureDataAccess
    )  # static # readonly
    PrecisionType: IPSetPrecision  # readonly
    RidgeFile: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.RidgeFile
    )  # readonly
    RidgeFileExists: bool  # readonly
    SampleDataPath: str  # readonly
    SampleFeatureDetector: SampleFeatureDetector  # readonly
    SampleFeatures: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures
    )  # readonly
    SampleRidges: (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleRidges
    )  # readonly
    ScanConditionList: System.Collections.Generic.List[ScanConditions]  # readonly
    ScanRejectionFlagValueTable: System.Data.DataTable
    SchemaDefaultDirectory: str

    def UpdateDelayInformation(self, psetDeviceDelay: IPSetDeviceDelayInfo) -> None: ...
    @overload
    def FindSampleFeatures(
        self,
    ) -> Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures: ...
    @overload
    def FindSampleFeatures(
        self, rdParams: RidgeDetectionParams, fdParams: FeatureDetectionParams
    ) -> Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.SampleFeatures: ...
    @overload
    def ReadSpectrum(
        self, spectrumRequest: IPSetExtractSpectrum
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self,
        spectrumRequest: IPSetExtractSpectrum,
        backgroundSpecArrayToSubtract: List[ISpectrum],
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self, specType: SpecType, scanIDArray: List[int]
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(self, scanNumber: int, bMassUnits: bool) -> ISpectrum: ...
    @overload
    def ReadSpectrum(
        self,
        apseParameters: IPSetPeakSpectrumExtraction,
        specRequest: IPSetExtractSpectrum,
        sourceChromatogram: IChromatogram,
        backgroundSpectrum: List[ISpectrum],
        peakNumber: int,
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self,
        specType: SpecType,
        scanIDArray: List[int],
        desiredStorageMode: DesiredMSStorageType,
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self,
        specRequest: IPSetExtractSpectrum,
        apseParameters: IPSetPeakSpectrumExtraction,
        peakIDParam: IPSetPeakID,
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self,
        specRequest: IPSetExtractSpectrum,
        apseParameters: IPSetPeakSpectrumExtraction,
        peakIDParam: IPSetPeakID,
        startEndTimeRanges: IPSetRangeCollection,
    ) -> List[ISpectrum]: ...
    @overload
    def ReadSpectrum(
        self, rowIndex: int, bMassUnits: bool, desiredStorageMode: DesiredMSStorageType
    ) -> ISpectrum: ...
    @overload
    @staticmethod
    def GetInstance(
        sampleDataDir: str,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.TofFeatureDataAccess
    ): ...
    @overload
    @staticmethod
    def GetInstance(
        sampleDataDir: str, numberFormat: INumericFormat
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.TofFeatureDataAccess
    ): ...
    @staticmethod
    def GetTofDataConversion() -> (
        Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.ITofDataConversion
    ): ...
    def Dispose(self) -> None: ...
    def RefreshDataFile(self, isNewDataPresent: bool) -> bool: ...
    def GetSampleValue(self, internalName: str) -> str: ...
    def CloseDataFile(self) -> None: ...
    def GetActuals(self, timeInMins: float) -> System.Data.DataSet: ...
    def GetActualValue(
        self, actualDisplayName: str, xArray: List[float], yArray: List[float]
    ) -> None: ...
    def GetTimeSegmentsIDArray(self) -> List[int]: ...
    def GetDeviceSignalInfo(
        self,
    ) -> System.Collections.Generic.List[NonMSDataPoint]: ...
    @staticmethod
    def ClearCache() -> None: ...
    def GetFeatureSet(self, scanConditions: ScanConditions) -> IFeatureSet: ...
    @overload
    def GetSampleData(self, category: SampleCategory) -> System.Data.DataSet: ...
    @overload
    def GetSampleData(self, internalNamePrefix: str) -> System.Data.DataSet: ...
    def GetTotalRidgeCount(self) -> int: ...
    def GetDataDependentScanInfo(self) -> IBdaMsScanRecordCollection: ...
    @overload
    def SaveUserCalibration(self, psetTofCalib: IPSetTofCalibration) -> None: ...
    @overload
    def SaveUserCalibration(
        self, specArray: List[ISpectrum], psetTofCalib: IPSetTofCalibration
    ) -> None: ...
    def GetSaturatedFeatureCount(self) -> int: ...
    def ClearScanRejectionFlagValueTable(self) -> None: ...
    def GetSignals(self, deviceKey: str) -> System.Collections.Generic.List[str]: ...
    def IsActualsPresent(self) -> bool: ...
    @overload
    def ReadChromatogram(
        self, extractParamSet: IPSetExtractChrom
    ) -> List[IChromatogram]: ...
    @overload
    def ReadChromatogram(
        self, extractParamSet: IPSetExtractChrom, excludeParamSet: IPSetExcludeMass
    ) -> List[IChromatogram]: ...
    def SetUnitPrecisionValue(
        self, psetUnits: IPSetUnits, psetPrecision: IPSetPrecision
    ) -> None: ...
    def GetTimeSegmentDetails(self, timesegmentID: int, numOfScans: int) -> IRange: ...
    def GetTimeSegmentRanges(self) -> RangeCollection: ...
    def GetActualNames(self) -> List[str]: ...
    def IsFileOpen(self) -> bool: ...
    def IsUserCalibrationPresent(self) -> bool: ...
    @overload
    def OpenDataFile(self, dataDir: str, bOptimizeFileHandling: bool) -> bool: ...
    @overload
    def OpenDataFile(self, dataDir: str) -> bool: ...
    def IsAcquisitionStatusComplete(self) -> bool: ...
    @staticmethod
    def ClearCacheExcept(
        tfda: Agilent.MassSpectrometry.DataAnalysis.FeatureDataAccess.TofFeatureDataAccess,
    ) -> None: ...
    def GetScanRecordsInfo(
        self, scanType: MSScanType
    ) -> IBdaMsScanRecordCollection: ...
    def ClearUserCalibration(self) -> None: ...
    def GetTotalFeatureCount(self) -> int: ...
    def UpdateMassCalibration(
        self, referenceMZValues: Dict[Feature, float], A: float, T0: float
    ) -> str: ...
    def SetUnitValue(self, psetUnits: IPSetUnits) -> None: ...
    def GetRidgeSet(self, scanConditions: ScanConditions) -> IRidgeSet: ...
    def PersistScanRejectionFlagValueTable(self) -> None: ...
    def IsDataDependentScanInfoPresent(self) -> bool: ...
    def GetMsDeviceDelayTime(self, dDelay: float) -> bool: ...
    def GetElementNameCollection(self, timesegmentID: int) -> Dict[float, str]: ...
